EpsonConfig class

Constructors

EpsonConfig({EpsonPortType portType = EpsonPortType.all, EpsonPrinterSeries printerSeries = EpsonPrinterSeries.tmP80ii, String modelLang = 'ank', int connectTimeoutMs = 10000, int sendTimeoutMs = 10000, int autoDisconnectMs = 20000})
const

Properties

autoDisconnectMs int
final
connectTimeoutMs int
final
hashCode int
The hash code for this object.
no setterinherited
modelLang String
ePOS language model. "ank" is the default Epson sample value.
final
portType EpsonPortType
ePOS discovery port type. Use EpsonPortType.bluetoothLe for BLE-only discovery, or EpsonPortType.bluetooth for MFi Bluetooth Classic.
final
printerSeries EpsonPrinterSeries
Printer model used to create the ePOS printer instance.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendTimeoutMs int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited